@@ -1,11 +1,6 @@
 package POEx::IRC::Backend::Connector;
-{
-  $POEx::IRC::Backend::Connector::VERSION = '0.024005';
-}
-use strictures 1;
+$POEx::IRC::Backend::Connector::VERSION = '0.024006';
 use Moo;
-use namespace::clean;
-
 with 'POEx::IRC::Backend::Role::Connector';
 
 has args => (
@@ -25,6 +20,8 @@ has bindaddr => (
 
 =pod
 
+=for Pod::Coverage has_\w+
+
 =head1 NAME
 
 POEx::IRC::Backend::Connector - An outgoing connector
